"""Top-level package for FEniCS-Plotly."""

__author__ = """Henrik Finsberg"""
__email__ = "henriknf@simula.no"
__version__ = "0.1.4"

from .fenics_plotly import plot, set_renderer

__all__ = ["plot", "set_renderer"]
